==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-68.js <==
dispMUA.arDispMUAAllocation["h"] =
{
  "html newsletter (www.cybershop.de)" : [ "cybershop_de.png" , "http://www.cybershop.de/" ] ,
  "http://www.proautoresponder.com/" : [ "proautoresponder_com.png" , "http://www.proautoresponder.com/" ] ,
  "http://www.courier-mta.org/cone/" : [ "cone.png" , "http://www.courier-mta.org/cone/" ] ,
  "http://www.umailcampaign.com" : [ "umailcampaign_com.png" , "http://www.umailcampaign.com/" ] ,
  "http://newsgroup.virgilio.it" : [ "virgilio.png" , "http://newsgroup.virgilio.it/" ] ,
  "horde application framework" : [ "horde.png" ] ,
  "http://www.phpclasses.org" : [ "phpclasses.png" , "http://www.phpclasses.org/" ] ,
  "http://www.postblitz.net" : [ "postblitz.png" , "http://www.postblitz.net/" ] ,
  "hostpoint generic mailer" : [ "hostpoint.png" , "http://www.hostpoint.ch/" ] ,
  "http://www.spamcop.net/" : [ "spamcop.png" , "http://www.spamcop.net/" ] ,
  "http://www.letterit.de" : [ "letterit.png" , "http://www.letterit.de/" ] ,
  "http://www.9cays.com" : [ "9cays_com.png" , "http://www.9cays.com/" ] ,
  "http://niusy.onet.pl" : [ "onet_pl.png" , "http://niusy.onet.pl/" ] ,
  "http://sub.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
  "hula modweb module" : [ "hula.png" ] ,
  "helpdesk webmail" : [ "islandnet.png" , "http://helpdesk.islandnet.com/" ] ,
  "heise emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "highwire mailer" : [ "highwire_mailer.png" ] ,
  "html mime mail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "highpoint-smtp" : [ "highpoint.png" , "http://www.highpoint-tech.com/" ] ,
  "heirloom mailx" : [ "heirloom_mailx.png" , "http://heirloom.sourceforge.net/mailx.html" ] ,
  "hinet webmail" : [ "hinet_net.png" , "http://webmail.hinet.net/" ] ,
  "hifi-forum.de" : [ "hifi-forum_de.png" , "http://www.hifi-forum.de/" ] ,
  "htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "holidaycheck" : [ "holidaycheck.png" , "http://www.holidaycheck.de/" ] ,
  "hidemarumail" : [ "hidemaru.png" ] ,
  "hhde webmail" : [ "hhde.png" ] ,
  "hp openview" : [ "hp_openview.png" , "http://www.openview.hp.com/" ] ,
  "hogwasher" : [ "hogwasher.png" ] ,
  "hastymail" : [ "hastymail.png" ] ,
  "home.ro" : [ "home_ro.png" , "http://www.home.ro/" ] ,
  "home.pl" : [ "home_pl.png" , "http://home.pl/" ] ,
  "hamster" : [ "hamster.png" ] ,
  "hot.ee" : [ "elion_hot.png" , "http://portal.hot.ee/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-68.js <==
dispMUA.arDispMUAAllocation["h"] =
{
  "html newsletter (www.cybershop.de)" : [ "cybershop_de.png" , "http://www.cybershop.de/" ] ,
  "http://www.proautoresponder.com/" : [ "proautoresponder_com.png" , "http://www.proautoresponder.com/" ] ,
  "http://www.courier-mta.org/cone/" : [ "cone.png" , "http://www.courier-mta.org/cone/" ] ,
  "http://www.umailcampaign.com" : [ "umailcampaign_com.png" , "http://www.umailcampaign.com/" ] ,
  "http://newsgroup.virgilio.it" : [ "virgilio.png" , "http://newsgroup.virgilio.it/" ] ,
  "horde application framework" : [ "horde.png" ] ,
  "http://www.phpclasses.org" : [ "phpclasses.png" , "http://www.phpclasses.org/" ] ,
  "http://www.postblitz.net" : [ "postblitz.png" , "http://www.postblitz.net/" ] ,
  "hostpoint generic mailer" : [ "hostpoint.png" , "http://www.hostpoint.ch/" ] ,
  "http://www.spamcop.net/" : [ "spamcop.png" , "http://www.spamcop.net/" ] ,
  "http://www.letterit.de" : [ "letterit.png" , "http://www.letterit.de/" ] ,
  "http://nntp.angelsk.ru" : [ "nntp_angelsk_ru.png" , "http://nntp.angelsk.ru/" ] ,
  "http://www.9cays.com" : [ "9cays_com.png" , "http://www.9cays.com/" ] ,
  "http://niusy.onet.pl" : [ "onet_pl.png" , "http://niusy.onet.pl/" ] ,
  "http://sub.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
  "hula modweb module" : [ "hula.png" ] ,
  "http://www.payu.pl" : [ "payu_pl.png" , "http://www.payu.pl/" ] ,
  "helpdesk webmail" : [ "islandnet.png" , "http://helpdesk.islandnet.com/" ] ,
  "heise emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "highwire mailer" : [ "highwire_mailer.png" ] ,
  "html mime mail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "highpoint-smtp" : [ "highpoint.png" , "http://www.highpoint-tech.com/" ] ,
  "heirloom mailx" : [ "heirloom_mailx.png" , "http://heirloom.sourceforge.net/mailx.html" ] ,
  "hinet webmail" : [ "hinet_net.png" , "http://webmail.hinet.net/" ] ,
  "hifi-forum.de" : [ "hifi-forum_de.png" , "http://www.hifi-forum.de/" ] ,
  "htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "holidaycheck" : [ "holidaycheck.png" , "http://www.holidaycheck.de/" ] ,
  "hidemarumail" : [ "hidemaru.png" ] ,
  "hhde webmail" : [ "hhde.png" ] ,
  "hp openview" : [ "hp_openview.png" , "http://www.openview.hp.com/" ] ,
  "hogwasher" : [ "hogwasher.png" ] ,
  "hastymail" : [ "hastymail.png" ] ,
  "hotel.de" : [ "hotel_de.png" , "http://www.hotel.de/" ] ,
  "helpspot" : [ "helpspot.png" , "http://www.userscape.com/" ] ,
  "home.ro" : [ "home_ro.png" , "http://www.home.ro/" ] ,
  "home.pl" : [ "home_pl.png" , "http://home.pl/" ] ,
  "hamster" : [ "hamster.png" ] ,
  "hot.ee" : [ "elion_hot.png" , "http://portal.hot.ee/" ] ,
  "h+bedv" : [ "avira.png" , "http://www.free-av.de/" ] ,
  "hafas" : [ "db.png" , "http://bahn.hafas.de/" ] ,
}
